@@ -7,7 +7,7 @@ License: Public Domain
 Documentation: http://hxlstandard.org
 """
 
-import logging, os
+import os
 
 import requests_cache
 from flask import Flask, g, request
@@ -16,7 +16,7 @@ from flask_caching import Cache
 import werkzeug.datastructures
 from . import reverse_proxied
 
-__version__="1.21"
+__version__="1.21.2"
 """Module version number
 See https://www.python.org/dev/peps/pep-0396/
 """
@@ -24,9 +24,6 @@ See https://www.python.org/dev/peps/pep-0396/
 # Main application object
 app = Flask(__name__)
 
-# Disable default logging (we'll add any log handlers explicitly in deployment)
-app.logger.addHandler(logging.NullHandler())
-
 # Handle subpaths
 app.wsgi_app = reverse_proxied.ReverseProxied(app.wsgi_app)
 
